@@ -213,7 +213,7 @@ class Core(Component):
             self.env.log.info('task is finished: %s' % task_id)
 
 
-class Ticker():
+class Ticker(object):
     """
     A Ticker is simply a simply timer that will repeatly wake up.
     """
@@ -300,7 +300,7 @@ class Ticker():
             self.timer.join()
 
 
-class CronConfig():
+class CronConfig(object):
     """
     This class read and write configuration for TracCronPlugin
     """
