@@ -10,7 +10,7 @@ Created on 28 oct. 2010
 ##
 ###############################################################################
 from datetime import datetime, timedelta
-from time import time, localtime
+from time import strptime, time, localtime
 
 from trac.ticket.model import Ticket
 from trac.config import BoolOption, IntOption, Option
@@ -509,10 +509,11 @@ class TicketDeadlineTask(Component):
 
     def need_notify(self, now, deadline, date_format, days_before):
         try:
-            due_date = datetime.strptime(deadline, date_format)
+            # don't use datetime.strptime for 2.4 compatibility
+            due_date = datetime(*strptime(deadline, date_format)[:6])
             due_date = due_date - timedelta(days=int(days_before))
-        except:
-            self.env.log.error('cannot convert deadline: %s' % due_date)
+        except Exception, e:
+            self.env.log.error('cannot convert %s: %s' % (deadline, e))
         else:
             self.env.log.debug('need_notify: %s, %s' % (now, due_date))
             return now >= due_date
